@@ -44,7 +44,7 @@ package Astro::Coord::ECI::Sun;
 use strict;
 use warnings;
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 use base qw{Astro::Coord::ECI};
 
@@ -489,6 +489,10 @@ eod
     return $self;
 }
 
+# The Sun is normally positioned in inertial coordinates.
+
+sub _initial_inertial { return 1 }
+
 1;
 
 =back
